AGW Logo

svn SVN Revision 68486 For customtreectrl

This file contains the SVN revision history for customtreectrl, at revision 68486.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 10-Dec-2009 18:09:38 UTC
  • Committer: AG
  • File Size: 263659 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

CustomTreeCtrl: Correct GetLineHeight for the silly new “true division” behaviour of Python. Thanks to Nat Echols for the bug report.


svn_diff Diff To Previous Version (68455)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/07/29 20:09:55     68455
+++ wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/08/01 18:16:47     68486
@@ -3,7 +3,7 @@
# Inspired By And Heavily Based On wxGenericTreeCtrl.
#
# Andrea Gavana, @ 17 May 2006
# Latest Revision: 29 Jul 2011, 21.00 GMT
#
#
# TODO List
@@ -212,7 +212,7 @@

CustomTreeCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 29 Jul 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 01 Aug 2011, 20.00 GMT

Version 2.4

@@ -5476,9 +5476,9 @@
"""

if self.GetAGWWindowStyleFlag() & TR_HAS_VARIABLE_ROW_HEIGHT:
-            return item.GetHeight()
+            return int(item.GetHeight())
else:
-            return self._lineHeight
+            return int(self._lineHeight)


def DrawVerticalGradient(self, dc, rect, hasfocus):
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 17 May 2006
-# Latest Revision: 29 Jul 2011, 21.00 GMT
+# Latest Revision: 01 Aug 2011, 20.00 GMT
#
#
Tree